@@ -277,6 +277,10 @@ def bind( F, **kwargs ):
         return F(*liveargs,**k)
     return binder
 
+# =============================================================================
+# generic class
+# =============================================================================
+
 class Generic(object):
     """ An object which can be used as a generic store.
         Constructions by keyword:        
@@ -295,7 +299,7 @@ class Generic(object):
             g.f = f
             g.f(2) --> 4
 
-        This works as well with bound function, e.g. 
+        This works as well with bound functions, e.g. 
             def F(self,a):
                 self.a = a            # set the value of the 'g' object
             g.F = MethodType(F)
@@ -303,11 +307,6 @@ class Generic(object):
             g.F(1)
             g.a --> 1
             
-        
-        However, functions are _not_ copied when at construction or when merging one Generic
-        into another. This because the best u
-    
-            
     Hans Buehler, 2013
     """
     
@@ -315,7 +314,7 @@ class Generic(object):
         """ Initialize object; use keyword notation such as
                 Generic(a=1, b=2)                
             The 'vargs' argument allows passing on existing Generic, dict or generic objects;
-            see merge() for further information
+            see update() for further information
         """
         # allow construction the object as Generic(a=1,b=2)
         self.update(*vargs,**kwargs)
